from TheSilent.arp_void import *
from TheSilent.brute_force_hash import *
from TheSilent.clear import *
from TheSilent.dictionary_hash import *
from TheSilent.email_scanner import *
from TheSilent.form_scanner import *
from TheSilent.ftp_cracker import *
from TheSilent.hex_viewer import *
from TheSilent.link_scanner import *
from TheSilent.login_cracker import *
from TheSilent.packet_sniffer import *
from TheSilent.secure_overwrite import *
from TheSilent.security_scanner import *
from TheSilent.source_code_viewer import *
from TheSilent.sql_injection_scanner import *
from TheSilent.subdomain_scanner import *
from TheSilent.subdomain_takeover import *
from TheSilent.vuln_scanner import *
from TheSilent.xss_scanner import *



from TheSilent.clear import *

import codecs

cyan = "\033[1;36m"

def hex_viewer(file):
    clear()

    count = 0

    my_string = ""
    
    with open(file, "rb") as f:
        for chunk in iter(lambda: f.read(2), b""):
            try:
                hex_code = codecs.decode(chunk, "hex")
                clean = str(hex_code).replace("b", "")
                clean = clean.replace("'", "")
                clean = clean.replace("\\", "")
                clean = clean.replace("x", "")

                my_string += clean

                count += 1

                if count == 64:
                    print(cyan + my_string)
                    
                    count = 0
                    my_string = ""
                    
            except:
                pass

    print(cyan + "\ndone")
